summaryrefslogtreecommitdiff
path: root/lib/event.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/event.php')
-rw-r--r--lib/event.php22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/event.php b/lib/event.php
index 4ccee17e6..4819b71b4 100644
--- a/lib/event.php
+++ b/lib/event.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* utilities for defining and running event handlers
*
@@ -20,27 +20,27 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Event
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @copyright 2008 Control Yourself, Inc.
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
+ * @copyright 2008 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
/**
* Class for events
*
* This "class" two static functions for managing events in the Laconica code.
*
* @category Event
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*
* @todo Define a system for using Event instances
*/
@@ -54,7 +54,7 @@ class Event {
/**
* Add an event handler
*
* To run some code at a particular point in Laconica processing.
* Named events include receiving an XMPP message, adding a new notice,
* or showing part of an HTML page.
*
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* utilities for defining and running event handlers
@@ -20,27 +20,27 @@
* Class for events
*
- * This "class" two static functions for managing events in the Laconica code.
+ * This "class" two static functions for managing events in the StatusNet code.
*
* @category Event
@@ -54,7 +54,7 @@ class Event {
* Add an event handler
*
- * To run some code at a particular point in Laconica processing.
+ * To run some code at a particular point in StatusNet processing.
* Named events include receiving an XMPP message, adding a new notice,
* or showing part of an HTML page.